@@ -37,7 +37,7 @@ KMahjonggBackgroundSelector::~KMahjonggBackgroundSelector()
 
 void KMahjonggBackgroundSelector::setupData(KConfigSkeleton * aconfig)
 {
-    //Get our currently configured Tileset entry
+    //Get our currently configured background entry
     KConfig * config = aconfig->config();
     KConfigGroup group = config->group("General");
     QString initialGroup = group.readEntry("Background_file");
@@ -49,7 +49,7 @@ void KMahjonggBackgroundSelector::setupData(KConfigSkeleton * aconfig)
 
     //Now get our backgrounds into a list
     QStringList bgsAvailable;
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "kmahjongglib/backgrounds/", QStandardPaths::LocateDirectory);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "kmahjongglib/backgrounds", QStandardPaths::LocateDirectory);
     Q_FOREACH (const QString& dir, dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
         Q_FOREACH (const QString& file, fileNames) {
@@ -66,7 +66,7 @@ void KMahjonggBackgroundSelector::setupData(KConfigSkeleton * aconfig)
         if (abg->load(bgpath,backgroundPreview->width(),backgroundPreview->height())) {
             backgroundMap.insert(abg->authorProperty(namestr), abg);
             backgroundList->addItem(abg->authorProperty(namestr));
-            //Find if this is our currently configured Tileset
+            //Find if this is our currently configured background
             if (bgpath==initialGroup) {
                 //Select current entry
                 backgroundList->setCurrentRow(numvalidentries);
